# Table of Contents

- [interface-modeling-guidelines](<./interface-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Interface Modeling Guidelines](<./Interface-Modeling-Guidelines.md>)
  - [Definition](<./Interface-Modeling-Guidelines/Definition.md>)
  - [Description](<./Interface-Modeling-Guidelines/Description.md>)
  - [Interface Fact Sheet Subtypes](<./Interface-Modeling-Guidelines/Interface-Fact-Sheet-Subtypes.md>)
  - [Guidelines and Best Practices](<./Interface-Modeling-Guidelines/Guidelines-and-Best-Practices.md>)
  - [Understanding Interface Providers and Consumers](<./Interface-Modeling-Guidelines/Understanding-Interface-Providers-and-Consumers.md>)
  - [Capturing the Direction of the Data Flow](<./Interface-Modeling-Guidelines/Capturing-the-Direction-of-the-Data-Flow.md>)
  - [How to Model Interfaces](<./Interface-Modeling-Guidelines/How-to-Model-Interfaces.md>)
  - [How to Model Middleware](<./Interface-Modeling-Guidelines/How-to-Model-Middleware.md>)
  - [How to Model REST APIs](<./Interface-Modeling-Guidelines/How-to-Model-REST-APIs.md>)
  - [How to Model MCP Servers](<./Interface-Modeling-Guidelines/How-to-Model-MCP-Servers.md>)
  - [How to Model an Enterprise Service Bus (ESB)](<./Interface-Modeling-Guidelines/How-to-Model-an-Enterprise-Service-Bus-ESB.md>)
  - [Antipatterns](<./Interface-Modeling-Guidelines/Antipatterns.md>)
  - [Applicable Use Cases](<./Interface-Modeling-Guidelines/Applicable-Use-Cases.md>)
  - [Insights from the Interface Fact Sheet](<./Interface-Modeling-Guidelines/Insights-from-the-Interface-Fact-Sheet.md>)
  - [Related Information](<./Interface-Modeling-Guidelines/Related-Information.md>)
  - [Was this page helpful?](<./Interface-Modeling-Guidelines/Was-this-page-helpful.md>)
